@@ -334,13 +334,13 @@ class Database(core.Construct):
             )
 
             self._instance.node.find_child("Resource").add_property_override(
-                "SnapshotIdentifier", database_snapshot_id
+                "DBSnapshotIdentifier", database_snapshot_id
             )
             # While creating an RDS from a snapshot, MasterUsername cannot be specified
             self._instance.node.find_child("Resource").add_property_override(
                 "MasterUsername", None
             )
-            
+
             self._instance.add_rotation_single_user(
                 automatically_after=core.Duration.days(30)
             )
