@@ -105,6 +105,7 @@ class Microservice(core.Construct):
         
         will_use_ldap (str): Wether or not the EC2 instance should be able to integrate with LDAP. This configuration set-up the LDAP client security group to the EC2
 
+        existing_efs_security_group (str): In case you want to enble access to an existing EFS, provide its already-existing security group
     """
 
     @property
@@ -197,6 +198,24 @@ class Microservice(core.Construct):
             aws_ec2.UserData: the user-data used by the EC2 instance on boot
         """
         return self.base_user_data
+    
+    @property
+    def efs(self):
+        """Return the EFS resource, in case it was created
+
+        Returns:
+            aws_efs.FileSystem: he EFS resource
+        """
+        return self._efs
+    
+    @property
+    def efs_security_group(self):
+        """Return the EFS's security group, in case it was created
+
+        Returns:
+            aws_ec2.SecurityGroup: the security group in use by the EFS FileSystem
+        """
+        return self._efs_security_group
 
     def enable_fao_private_access(self, security_group):
         """Apply the correct ingress rules to the provided security group to enable access from the FAO internal networks
@@ -510,6 +529,7 @@ class Microservice(core.Construct):
         user_info_endpoint=None,
         will_use_ldap=None,
         additional_variables: dict = None,
+        existing_efs_security_group = None,
         **kwargs
     ):
         super().__init__(scope, id, **kwargs)
@@ -997,11 +1017,16 @@ class Microservice(core.Construct):
         # ~~~~~~~~~~~~~~~~
         # EFS
         # ~~~~~~~~~~~~~~~~
+        self._efs = None
+        self._efs_security_group = None
+
         if create_efs:
             # efs_key = _kms.Key.from_key_arn(self, "efs_key", aws_account["kms_ebs_key"])
-            efs = _efs.FileSystem(self, main_component_name+"efs", vpc=self._vpc, encrypted=False)
+            self._efs = _efs.FileSystem(self, main_component_name+"efs", vpc=self._vpc, encrypted=False)
             # you will find an additional EFS instruction after ASG
 
+            self._efs_security_group = self.efs.node.find_child("EfsSecurityGroup")
+
         # ~~~~~~~~~~~~~~~~
         # User data
         # ~~~~~~~~~~~~~~~~
@@ -1066,7 +1091,7 @@ class Microservice(core.Construct):
         )
         if create_efs:
             self.base_user_data = self.base_user_data.replace(
-                "_EFS_", efs.file_system_id
+                "_EFS_", self.efs.file_system_id
             )
 
         if has_additional_variables:
@@ -1160,7 +1185,7 @@ class Microservice(core.Construct):
         # ~~~~~~~~~~~~~~~~
         if create_efs:
             # EFS is created above
-            efs.connections.allow_default_port_from(self._asg)
+            self.efs.connections.allow_default_port_from(self._asg)
 
         # Add EC2 security group
         self.ec2_security_group = _ec2.SecurityGroup(
@@ -1177,6 +1202,21 @@ class Microservice(core.Construct):
         )
         self._asg.add_security_group(self.ec2_security_group)
 
+        # Enable access to already existing EFS
+        if existing_efs_security_group:
+            existing_efs_security_group_resource = _ec2.SecurityGroup.from_security_group_id(
+                self,
+                "existing_efs_security_group",
+                existing_efs_security_group,
+                mutable=False,
+            )
+
+            existing_efs_security_group_resource.add_ingress_rule(
+                peer=self.ec2_security_group,
+                connection=_ec2.Port.tcp(2049),
+                description="EFS access from EC2 " + app_name,
+            )
+
         # Add mandatory FAO security groups
         # Bastion host access
         bastion_host_security_group = _ec2.SecurityGroup.from_security_group_id(
